package test;

import org.jbpm.api.Configuration;
import org.jbpm.api.Execution;
import org.jbpm.api.ProcessInstance;
import org.jbpm.api.job.Job;
import org.jbpm.api.model.OpenExecution;
import org.jbpm.test.JbpmTestCase;
import java.util.*;
import java.lang.String;


/**
 * @author Rachel Hodos
 */
public class ConcurrencyTest extends JbpmTestCase {

  protected synchronized void initialize(){
    String cfgResource = getClass().getPackage().getName().replace(".","/")+"/jbpm.cfg.xml";
    //cfgResource = "/home/rhodos/dev/newpgs4/jbpm.cfg.xml";

    System.out.println(cfgResource);
    
    {
      log.debug("building ProcessEngine from resource " + cfgResource);
      System.err.println("building ProcessEngine from resource " + cfgResource);
    }

    Configuration configuration = new Configuration().setResource(cfgResource);

    processEngine = configuration.buildProcessEngine();
  }

  String deploymentId;
  
  protected void setUp() throws Exception {
    System.out.println("ConcurrencyTest, before super.setup()");  
    super.setUp();
    System.out.println("ConcurrencyTest, after super.setup()");  
  
    deploymentId = repositoryService.createDeployment()
    .addResourceFromClasspath("jpl/mipl/pgs/test/TestConcurrencySimple.jpdl.xml")
    .deploy();

    System.err.println("setUp completed...");
  }

  protected void tearDown() throws Exception {
    repositoryService.deleteDeploymentCascade(deploymentId);
    super.tearDown();
  }

  public void testActivityOrder() throws InterruptedException {
    ProcessInstance pi = executionService.startProcessInstanceByKey("TestConcurrencySimple");
   
    Collection<? extends Execution> child_exec = pi.getExecutions();
    Object[] child_exec_array  = child_exec.toArray();
    System.out.println("testActivityOrder: number of children = " + child_exec_array.length);
    
    for (int i=0; i<child_exec_array.length; i++){
    	//String exec_name = ((Execution) child_exec_array[i]).getName();
    	String executionId = ((Execution) child_exec_array[i]).getId();
    	System.out.println("testActivityOrder: signaling "+executionId);
    	executionService.signalExecutionById(executionId);
    }
    
  
  }

 
 public static void main(String[] args) throws Exception { 
	 System.out.println("ConcurrencyTest.main, beginning");
	  ConcurrencyTest ct = new ConcurrencyTest();
	  ct.setUp();
	  ct.testActivityOrder();
	 System.out.println("ConcurrencyTest.main, after testActivityOrder");
	  ct.tearDown();
	 System.out.println("concurrencyTest.main, after tearDown");
  }
 
}
